#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerversionDevicegrayQueryModel(object):

    def __init__(self):
        self._action_type = None
        self._app_origin = None
        self._bundle_id = None
        self._gray_code = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def app_origin(self):
        return self._app_origin

    @app_origin.setter
    def app_origin(self, value):
        self._app_origin = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def gray_code(self):
        return self._gray_code

    @gray_code.setter
    def gray_code(self, value):
        self._gray_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.app_origin:
            if hasattr(self.app_origin, 'to_alipay_dict'):
                params['app_origin'] = self.app_origin.to_alipay_dict()
            else:
                params['app_origin'] = self.app_origin
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.gray_code:
            if hasattr(self.gray_code, 'to_alipay_dict'):
                params['gray_code'] = self.gray_code.to_alipay_dict()
            else:
                params['gray_code'] = self.gray_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerversionDevicegrayQueryModel()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'app_origin' in d:
            o.app_origin = d['app_origin']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'gray_code' in d:
            o.gray_code = d['gray_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingVoucherConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherConfirmResponse, self).__init__()
        self._need_redirect = None
        self._open_id = None
        self._out_biz_no = None
        self._redirect_uri = None
        self._send_code = None
        self._template_id = None
        self._theme = None
        self._user_id = None

    @property
    def need_redirect(self):
        return self._need_redirect

    @need_redirect.setter
    def need_redirect(self, value):
        self._need_redirect = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def redirect_uri(self):
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, value):
        self._redirect_uri = value
    @property
    def send_code(self):
        return self._send_code

    @send_code.setter
    def send_code(self, value):
        self._send_code = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def theme(self):
        return self._theme

    @theme.setter
    def theme(self, value):
        self._theme = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherConfirmResponse, self).parse_response_content(response_content)
        if 'need_redirect' in response:
            self.need_redirect = response['need_redirect']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'redirect_uri' in response:
            self.redirect_uri = response['redirect_uri']
        if 'send_code' in response:
            self.send_code = response['send_code']
        if 'template_id' in response:
            self.template_id = response['template_id']
        if 'theme' in response:
            self.theme = response['theme']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class AlipayBossFncInvoiceStatementbillApplyModel(object):

    def __init__(self):
        self._biz_id = None
        self._biz_no = None
        self._invoice_amt = None
        self._invoice_type = None
        self._memo = None
        self._operator = None
        self._statement_bill_list = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def statement_bill_list(self):
        return self._statement_bill_list

    @statement_bill_list.setter
    def statement_bill_list(self, value):
        self._statement_bill_list = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.statement_bill_list:
            if hasattr(self.statement_bill_list, 'to_alipay_dict'):
                params['statement_bill_list'] = self.statement_bill_list.to_alipay_dict()
            else:
                params['statement_bill_list'] = self.statement_bill_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncInvoiceStatementbillApplyModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'statement_bill_list' in d:
            o.statement_bill_list = d['statement_bill_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationPromoterRelationCreateModel(object):

    def __init__(self):
        self._mini_app_id = None
        self._pid = None
        self._store_id = None
        self._user_id = None

    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationPromoterRelationCreateModel()
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'pid' in d:
            o.pid = d['pid']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class DatadigitalFincloudGeneralsaasFaceVerificationQueryResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudGeneralsaasFaceVerificationQueryResponse, self).__init__()
        self._alive_photo = None
        self._attack_flag = None
        self._certify_state = None
        self._quality = None
        self._score = None

    @property
    def alive_photo(self):
        return self._alive_photo

    @alive_photo.setter
    def alive_photo(self, value):
        self._alive_photo = value
    @property
    def attack_flag(self):
        return self._attack_flag

    @attack_flag.setter
    def attack_flag(self, value):
        self._attack_flag = value
    @property
    def certify_state(self):
        return self._certify_state

    @certify_state.setter
    def certify_state(self, value):
        self._certify_state = value
    @property
    def quality(self):
        return self._quality

    @quality.setter
    def quality(self, value):
        self._quality = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudGeneralsaasFaceVerificationQueryResponse, self).parse_response_content(response_content)
        if 'alive_photo' in response:
            self.alive_photo = response['alive_photo']
        if 'attack_flag' in response:
            self.attack_flag = response['attack_flag']
        if 'certify_state' in response:
            self.certify_state = response['certify_state']
        if 'quality' in response:
            self.quality = response['quality']
        if 'score' in response:
            self.score = response['score']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ScenicExtInfo import ScenicExtInfo


class AlipayBusinessItemTicketSyncModel(object):

    def __init__(self):
        self._ext_info = None
        self._name = None
        self._outer_scenic_id = None
        self._outer_ticket_id = None
        self._partner_id = None
        self._pic = None
        self._scenic_app_id = None
        self._source_system = None
        self._status = None
        self._ticket_goods_id = None
        self._ticket_link = None
        self._ticket_modified_time = None
        self._ticket_specs = None
        self._ticket_type = None
        self._update_msg = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, ScenicExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(ScenicExtInfo.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def outer_scenic_id(self):
        return self._outer_scenic_id

    @outer_scenic_id.setter
    def outer_scenic_id(self, value):
        self._outer_scenic_id = value
    @property
    def outer_ticket_id(self):
        return self._outer_ticket_id

    @outer_ticket_id.setter
    def outer_ticket_id(self, value):
        self._outer_ticket_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pic(self):
        return self._pic

    @pic.setter
    def pic(self, value):
        self._pic = value
    @property
    def scenic_app_id(self):
        return self._scenic_app_id

    @scenic_app_id.setter
    def scenic_app_id(self, value):
        self._scenic_app_id = value
    @property
    def source_system(self):
        return self._source_system

    @source_system.setter
    def source_system(self, value):
        self._source_system = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def ticket_goods_id(self):
        return self._ticket_goods_id

    @ticket_goods_id.setter
    def ticket_goods_id(self, value):
        self._ticket_goods_id = value
    @property
    def ticket_link(self):
        return self._ticket_link

    @ticket_link.setter
    def ticket_link(self, value):
        self._ticket_link = value
    @property
    def ticket_modified_time(self):
        return self._ticket_modified_time

    @ticket_modified_time.setter
    def ticket_modified_time(self, value):
        self._ticket_modified_time = value
    @property
    def ticket_specs(self):
        return self._ticket_specs

    @ticket_specs.setter
    def ticket_specs(self, value):
        if isinstance(value, list):
            self._ticket_specs = list()
            for i in value:
                self._ticket_specs.append(i)
    @property
    def ticket_type(self):
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, value):
        self._ticket_type = value
    @property
    def update_msg(self):
        return self._update_msg

    @update_msg.setter
    def update_msg(self, value):
        self._update_msg = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.outer_scenic_id:
            if hasattr(self.outer_scenic_id, 'to_alipay_dict'):
                params['outer_scenic_id'] = self.outer_scenic_id.to_alipay_dict()
            else:
                params['outer_scenic_id'] = self.outer_scenic_id
        if self.outer_ticket_id:
            if hasattr(self.outer_ticket_id, 'to_alipay_dict'):
                params['outer_ticket_id'] = self.outer_ticket_id.to_alipay_dict()
            else:
                params['outer_ticket_id'] = self.outer_ticket_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pic:
            if hasattr(self.pic, 'to_alipay_dict'):
                params['pic'] = self.pic.to_alipay_dict()
            else:
                params['pic'] = self.pic
        if self.scenic_app_id:
            if hasattr(self.scenic_app_id, 'to_alipay_dict'):
                params['scenic_app_id'] = self.scenic_app_id.to_alipay_dict()
            else:
                params['scenic_app_id'] = self.scenic_app_id
        if self.source_system:
            if hasattr(self.source_system, 'to_alipay_dict'):
                params['source_system'] = self.source_system.to_alipay_dict()
            else:
                params['source_system'] = self.source_system
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.ticket_goods_id:
            if hasattr(self.ticket_goods_id, 'to_alipay_dict'):
                params['ticket_goods_id'] = self.ticket_goods_id.to_alipay_dict()
            else:
                params['ticket_goods_id'] = self.ticket_goods_id
        if self.ticket_link:
            if hasattr(self.ticket_link, 'to_alipay_dict'):
                params['ticket_link'] = self.ticket_link.to_alipay_dict()
            else:
                params['ticket_link'] = self.ticket_link
        if self.ticket_modified_time:
            if hasattr(self.ticket_modified_time, 'to_alipay_dict'):
                params['ticket_modified_time'] = self.ticket_modified_time.to_alipay_dict()
            else:
                params['ticket_modified_time'] = self.ticket_modified_time
        if self.ticket_specs:
            if isinstance(self.ticket_specs, list):
                for i in range(0, len(self.ticket_specs)):
                    element = self.ticket_specs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ticket_specs[i] = element.to_alipay_dict()
            if hasattr(self.ticket_specs, 'to_alipay_dict'):
                params['ticket_specs'] = self.ticket_specs.to_alipay_dict()
            else:
                params['ticket_specs'] = self.ticket_specs
        if self.ticket_type:
            if hasattr(self.ticket_type, 'to_alipay_dict'):
                params['ticket_type'] = self.ticket_type.to_alipay_dict()
            else:
                params['ticket_type'] = self.ticket_type
        if self.update_msg:
            if hasattr(self.update_msg, 'to_alipay_dict'):
                params['update_msg'] = self.update_msg.to_alipay_dict()
            else:
                params['update_msg'] = self.update_msg
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBusinessItemTicketSyncModel()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'name' in d:
            o.name = d['name']
        if 'outer_scenic_id' in d:
            o.outer_scenic_id = d['outer_scenic_id']
        if 'outer_ticket_id' in d:
            o.outer_ticket_id = d['outer_ticket_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pic' in d:
            o.pic = d['pic']
        if 'scenic_app_id' in d:
            o.scenic_app_id = d['scenic_app_id']
        if 'source_system' in d:
            o.source_system = d['source_system']
        if 'status' in d:
            o.status = d['status']
        if 'ticket_goods_id' in d:
            o.ticket_goods_id = d['ticket_goods_id']
        if 'ticket_link' in d:
            o.ticket_link = d['ticket_link']
        if 'ticket_modified_time' in d:
            o.ticket_modified_time = d['ticket_modified_time']
        if 'ticket_specs' in d:
            o.ticket_specs = d['ticket_specs']
        if 'ticket_type' in d:
            o.ticket_type = d['ticket_type']
        if 'update_msg' in d:
            o.update_msg = d['update_msg']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundCouponWufuCardReceiveResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundCouponWufuCardReceiveResponse, self).__init__()
        self._card_id = None
        self._card_type = None

    @property
    def card_id(self):
        return self._card_id

    @card_id.setter
    def card_id(self, value):
        self._card_id = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundCouponWufuCardReceiveResponse, self).parse_response_content(response_content)
        if 'card_id' in response:
            self.card_id = response['card_id']
        if 'card_type' in response:
            self.card_type = response['card_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SceneContent(object):

    def __init__(self):
        self._article_classify = None
        self._author = None
        self._content_id = None
        self._cover = None
        self._image_list = None
        self._public_id = None
        self._public_name = None
        self._scheme = None
        self._scm = None
        self._summary = None
        self._title = None
        self._total_praise_count = None
        self._total_reply_count = None
        self._total_view_count = None
        self._type = None

    @property
    def article_classify(self):
        return self._article_classify

    @article_classify.setter
    def article_classify(self, value):
        self._article_classify = value
    @property
    def author(self):
        return self._author

    @author.setter
    def author(self, value):
        self._author = value
    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def image_list(self):
        return self._image_list

    @image_list.setter
    def image_list(self, value):
        if isinstance(value, list):
            self._image_list = list()
            for i in value:
                self._image_list.append(i)
    @property
    def public_id(self):
        return self._public_id

    @public_id.setter
    def public_id(self, value):
        self._public_id = value
    @property
    def public_name(self):
        return self._public_name

    @public_name.setter
    def public_name(self, value):
        self._public_name = value
    @property
    def scheme(self):
        return self._scheme

    @scheme.setter
    def scheme(self, value):
        self._scheme = value
    @property
    def scm(self):
        return self._scm

    @scm.setter
    def scm(self, value):
        self._scm = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def total_praise_count(self):
        return self._total_praise_count

    @total_praise_count.setter
    def total_praise_count(self, value):
        self._total_praise_count = value
    @property
    def total_reply_count(self):
        return self._total_reply_count

    @total_reply_count.setter
    def total_reply_count(self, value):
        self._total_reply_count = value
    @property
    def total_view_count(self):
        return self._total_view_count

    @total_view_count.setter
    def total_view_count(self, value):
        self._total_view_count = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.article_classify:
            if hasattr(self.article_classify, 'to_alipay_dict'):
                params['article_classify'] = self.article_classify.to_alipay_dict()
            else:
                params['article_classify'] = self.article_classify
        if self.author:
            if hasattr(self.author, 'to_alipay_dict'):
                params['author'] = self.author.to_alipay_dict()
            else:
                params['author'] = self.author
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.image_list:
            if isinstance(self.image_list, list):
                for i in range(0, len(self.image_list)):
                    element = self.image_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.image_list[i] = element.to_alipay_dict()
            if hasattr(self.image_list, 'to_alipay_dict'):
                params['image_list'] = self.image_list.to_alipay_dict()
            else:
                params['image_list'] = self.image_list
        if self.public_id:
            if hasattr(self.public_id, 'to_alipay_dict'):
                params['public_id'] = self.public_id.to_alipay_dict()
            else:
                params['public_id'] = self.public_id
        if self.public_name:
            if hasattr(self.public_name, 'to_alipay_dict'):
                params['public_name'] = self.public_name.to_alipay_dict()
            else:
                params['public_name'] = self.public_name
        if self.scheme:
            if hasattr(self.scheme, 'to_alipay_dict'):
                params['scheme'] = self.scheme.to_alipay_dict()
            else:
                params['scheme'] = self.scheme
        if self.scm:
            if hasattr(self.scm, 'to_alipay_dict'):
                params['scm'] = self.scm.to_alipay_dict()
            else:
                params['scm'] = self.scm
        if self.summary:
            if hasattr(self.summary, 'to_alipay_dict'):
                params['summary'] = self.summary.to_alipay_dict()
            else:
                params['summary'] = self.summary
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.total_praise_count:
            if hasattr(self.total_praise_count, 'to_alipay_dict'):
                params['total_praise_count'] = self.total_praise_count.to_alipay_dict()
            else:
                params['total_praise_count'] = self.total_praise_count
        if self.total_reply_count:
            if hasattr(self.total_reply_count, 'to_alipay_dict'):
                params['total_reply_count'] = self.total_reply_count.to_alipay_dict()
            else:
                params['total_reply_count'] = self.total_reply_count
        if self.total_view_count:
            if hasattr(self.total_view_count, 'to_alipay_dict'):
                params['total_view_count'] = self.total_view_count.to_alipay_dict()
            else:
                params['total_view_count'] = self.total_view_count
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SceneContent()
        if 'article_classify' in d:
            o.article_classify = d['article_classify']
        if 'author' in d:
            o.author = d['author']
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'cover' in d:
            o.cover = d['cover']
        if 'image_list' in d:
            o.image_list = d['image_list']
        if 'public_id' in d:
            o.public_id = d['public_id']
        if 'public_name' in d:
            o.public_name = d['public_name']
        if 'scheme' in d:
            o.scheme = d['scheme']
        if 'scm' in d:
            o.scm = d['scm']
        if 'summary' in d:
            o.summary = d['summary']
        if 'title' in d:
            o.title = d['title']
        if 'total_praise_count' in d:
            o.total_praise_count = d['total_praise_count']
        if 'total_reply_count' in d:
            o.total_reply_count = d['total_reply_count']
        if 'total_view_count' in d:
            o.total_view_count = d['total_view_count']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ActivityBaseInfo import ActivityBaseInfo
from alipay.aop.api.domain.PaymentVoucherBelongMerchantInfo import PaymentVoucherBelongMerchantInfo
from alipay.aop.api.domain.VoucherSummary import VoucherSummary
from alipay.aop.api.domain.VoucherAvailableScopeInfo import VoucherAvailableScopeInfo
from alipay.aop.api.domain.PaymentVoucherBudgetInfo import PaymentVoucherBudgetInfo
from alipay.aop.api.domain.VoucherBudgetSupplyInfo import VoucherBudgetSupplyInfo
from alipay.aop.api.domain.VoucherCustomerGuideInfo import VoucherCustomerGuideInfo
from alipay.aop.api.domain.VoucherDeductInfo import VoucherDeductInfo
from alipay.aop.api.domain.PaymentVoucherDisplayInfo import PaymentVoucherDisplayInfo
from alipay.aop.api.domain.VoucherDisplayPatternInfo import VoucherDisplayPatternInfo
from alipay.aop.api.domain.VoucherInventoryInfo import VoucherInventoryInfo
from alipay.aop.api.domain.VoucherSendModeInfo import VoucherSendModeInfo
from alipay.aop.api.domain.PaymentVoucherSendRule import PaymentVoucherSendRule
from alipay.aop.api.domain.PaymentVoucherUseRuleDetail import PaymentVoucherUseRuleDetail
from alipay.aop.api.domain.VoucherUseRuleInfo import VoucherUseRuleInfo


class AlipayMarketingActivityVoucherQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityVoucherQueryResponse, self).__init__()
        self._activity_base_info = None
        self._activity_id = None
        self._activity_name = None
        self._activity_status = None
        self._belong_merchant_info = None
        self._publish_end_time = None
        self._publish_start_time = None
        self._summary = None
        self._voucher_available_scope_info = None
        self._voucher_budget_info = None
        self._voucher_budget_supply_info = None
        self._voucher_customer_guide_info = None
        self._voucher_deduct_info = None
        self._voucher_display_info = None
        self._voucher_display_pattern_info = None
        self._voucher_inventory_info = None
        self._voucher_send_mode_info = None
        self._voucher_send_rule = None
        self._voucher_type = None
        self._voucher_use_rule = None
        self._voucher_use_rule_info = None

    @property
    def activity_base_info(self):
        return self._activity_base_info

    @activity_base_info.setter
    def activity_base_info(self, value):
        if isinstance(value, ActivityBaseInfo):
            self._activity_base_info = value
        else:
            self._activity_base_info = ActivityBaseInfo.from_alipay_dict(value)
    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def activity_name(self):
        return self._activity_name

    @activity_name.setter
    def activity_name(self, value):
        self._activity_name = value
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, PaymentVoucherBelongMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = PaymentVoucherBelongMerchantInfo.from_alipay_dict(value)
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def publish_start_time(self):
        return self._publish_start_time

    @publish_start_time.setter
    def publish_start_time(self, value):
        self._publish_start_time = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        if isinstance(value, VoucherSummary):
            self._summary = value
        else:
            self._summary = VoucherSummary.from_alipay_dict(value)
    @property
    def voucher_available_scope_info(self):
        return self._voucher_available_scope_info

    @voucher_available_scope_info.setter
    def voucher_available_scope_info(self, value):
        if isinstance(value, VoucherAvailableScopeInfo):
            self._voucher_available_scope_info = value
        else:
            self._voucher_available_scope_info = VoucherAvailableScopeInfo.from_alipay_dict(value)
    @property
    def voucher_budget_info(self):
        return self._voucher_budget_info

    @voucher_budget_info.setter
    def voucher_budget_info(self, value):
        if isinstance(value, PaymentVoucherBudgetInfo):
            self._voucher_budget_info = value
        else:
            self._voucher_budget_info = PaymentVoucherBudgetInfo.from_alipay_dict(value)
    @property
    def voucher_budget_supply_info(self):
        return self._voucher_budget_supply_info

    @voucher_budget_supply_info.setter
    def voucher_budget_supply_info(self, value):
        if isinstance(value, VoucherBudgetSupplyInfo):
            self._voucher_budget_supply_info = value
        else:
            self._voucher_budget_supply_info = VoucherBudgetSupplyInfo.from_alipay_dict(value)
    @property
    def voucher_customer_guide_info(self):
        return self._voucher_customer_guide_info

    @voucher_customer_guide_info.setter
    def voucher_customer_guide_info(self, value):
        if isinstance(value, VoucherCustomerGuideInfo):
            self._voucher_customer_guide_info = value
        else:
            self._voucher_customer_guide_info = VoucherCustomerGuideInfo.from_alipay_dict(value)
    @property
    def voucher_deduct_info(self):
        return self._voucher_deduct_info

    @voucher_deduct_info.setter
    def voucher_deduct_info(self, value):
        if isinstance(value, VoucherDeductInfo):
            self._voucher_deduct_info = value
        else:
            self._voucher_deduct_info = VoucherDeductInfo.from_alipay_dict(value)
    @property
    def voucher_display_info(self):
        return self._voucher_display_info

    @voucher_display_info.setter
    def voucher_display_info(self, value):
        if isinstance(value, PaymentVoucherDisplayInfo):
            self._voucher_display_info = value
        else:
            self._voucher_display_info = PaymentVoucherDisplayInfo.from_alipay_dict(value)
    @property
    def voucher_display_pattern_info(self):
        return self._voucher_display_pattern_info

    @voucher_display_pattern_info.setter
    def voucher_display_pattern_info(self, value):
        if isinstance(value, VoucherDisplayPatternInfo):
            self._voucher_display_pattern_info = value
        else:
            self._voucher_display_pattern_info = VoucherDisplayPatternInfo.from_alipay_dict(value)
    @property
    def voucher_inventory_info(self):
        return self._voucher_inventory_info

    @voucher_inventory_info.setter
    def voucher_inventory_info(self, value):
        if isinstance(value, VoucherInventoryInfo):
            self._voucher_inventory_info = value
        else:
            self._voucher_inventory_info = VoucherInventoryInfo.from_alipay_dict(value)
    @property
    def voucher_send_mode_info(self):
        return self._voucher_send_mode_info

    @voucher_send_mode_info.setter
    def voucher_send_mode_info(self, value):
        if isinstance(value, VoucherSendModeInfo):
            self._voucher_send_mode_info = value
        else:
            self._voucher_send_mode_info = VoucherSendModeInfo.from_alipay_dict(value)
    @property
    def voucher_send_rule(self):
        return self._voucher_send_rule

    @voucher_send_rule.setter
    def voucher_send_rule(self, value):
        if isinstance(value, PaymentVoucherSendRule):
            self._voucher_send_rule = value
        else:
            self._voucher_send_rule = PaymentVoucherSendRule.from_alipay_dict(value)
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value
    @property
    def voucher_use_rule(self):
        return self._voucher_use_rule

    @voucher_use_rule.setter
    def voucher_use_rule(self, value):
        if isinstance(value, PaymentVoucherUseRuleDetail):
            self._voucher_use_rule = value
        else:
            self._voucher_use_rule = PaymentVoucherUseRuleDetail.from_alipay_dict(value)
    @property
    def voucher_use_rule_info(self):
        return self._voucher_use_rule_info

    @voucher_use_rule_info.setter
    def voucher_use_rule_info(self, value):
        if isinstance(value, VoucherUseRuleInfo):
            self._voucher_use_rule_info = value
        else:
            self._voucher_use_rule_info = VoucherUseRuleInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityVoucherQueryResponse, self).parse_response_content(response_content)
        if 'activity_base_info' in response:
            self.activity_base_info = response['activity_base_info']
        if 'activity_id' in response:
            self.activity_id = response['activity_id']
        if 'activity_name' in response:
            self.activity_name = response['activity_name']
        if 'activity_status' in response:
            self.activity_status = response['activity_status']
        if 'belong_merchant_info' in response:
            self.belong_merchant_info = response['belong_merchant_info']
        if 'publish_end_time' in response:
            self.publish_end_time = response['publish_end_time']
        if 'publish_start_time' in response:
            self.publish_start_time = response['publish_start_time']
        if 'summary' in response:
            self.summary = response['summary']
        if 'voucher_available_scope_info' in response:
            self.voucher_available_scope_info = response['voucher_available_scope_info']
        if 'voucher_budget_info' in response:
            self.voucher_budget_info = response['voucher_budget_info']
        if 'voucher_budget_supply_info' in response:
            self.voucher_budget_supply_info = response['voucher_budget_supply_info']
        if 'voucher_customer_guide_info' in response:
            self.voucher_customer_guide_info = response['voucher_customer_guide_info']
        if 'voucher_deduct_info' in response:
            self.voucher_deduct_info = response['voucher_deduct_info']
        if 'voucher_display_info' in response:
            self.voucher_display_info = response['voucher_display_info']
        if 'voucher_display_pattern_info' in response:
            self.voucher_display_pattern_info = response['voucher_display_pattern_info']
        if 'voucher_inventory_info' in response:
            self.voucher_inventory_info = response['voucher_inventory_info']
        if 'voucher_send_mode_info' in response:
            self.voucher_send_mode_info = response['voucher_send_mode_info']
        if 'voucher_send_rule' in response:
            self.voucher_send_rule = response['voucher_send_rule']
        if 'voucher_type' in response:
            self.voucher_type = response['voucher_type']
        if 'voucher_use_rule' in response:
            self.voucher_use_rule = response['voucher_use_rule']
        if 'voucher_use_rule_info' in response:
            self.voucher_use_rule_info = response['voucher_use_rule_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NimitzQueryContext(object):

    def __init__(self):
        self._query_strategy = None
        self._query_token = None

    @property
    def query_strategy(self):
        return self._query_strategy

    @query_strategy.setter
    def query_strategy(self, value):
        self._query_strategy = value
    @property
    def query_token(self):
        return self._query_token

    @query_token.setter
    def query_token(self, value):
        self._query_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.query_strategy:
            if hasattr(self.query_strategy, 'to_alipay_dict'):
                params['query_strategy'] = self.query_strategy.to_alipay_dict()
            else:
                params['query_strategy'] = self.query_strategy
        if self.query_token:
            if hasattr(self.query_token, 'to_alipay_dict'):
                params['query_token'] = self.query_token.to_alipay_dict()
            else:
                params['query_token'] = self.query_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NimitzQueryContext()
        if 'query_strategy' in d:
            o.query_strategy = d['query_strategy']
        if 'query_token' in d:
            o.query_token = d['query_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayUserLevelInfo import AlipayUserLevelInfo


class AlipayDatabizCoreUserLevelGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDatabizCoreUserLevelGetResponse, self).__init__()
        self._user_level_infos = None

    @property
    def user_level_infos(self):
        return self._user_level_infos

    @user_level_infos.setter
    def user_level_infos(self, value):
        if isinstance(value, list):
            self._user_level_infos = list()
            for i in value:
                if isinstance(i, AlipayUserLevelInfo):
                    self._user_level_infos.append(i)
                else:
                    self._user_level_infos.append(AlipayUserLevelInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDatabizCoreUserLevelGetResponse, self).parse_response_content(response_content)
        if 'user_level_infos' in response:
            self.user_level_infos = response['user_level_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceCityfacilitatorVoucherConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceCityfacilitatorVoucherConfirmResponse, self).__init__()
        self._amount = None
        self._end_station = None
        self._end_station_name = None
        self._quantity = None
        self._start_station = None
        self._start_station_name = None
        self._status = None
        self._ticket_price = None
        self._ticket_type = None
        self._trade_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def end_station(self):
        return self._end_station

    @end_station.setter
    def end_station(self, value):
        self._end_station = value
    @property
    def end_station_name(self):
        return self._end_station_name

    @end_station_name.setter
    def end_station_name(self, value):
        self._end_station_name = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def start_station(self):
        return self._start_station

    @start_station.setter
    def start_station(self, value):
        self._start_station = value
    @property
    def start_station_name(self):
        return self._start_station_name

    @start_station_name.setter
    def start_station_name(self, value):
        self._start_station_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def ticket_price(self):
        return self._ticket_price

    @ticket_price.setter
    def ticket_price(self, value):
        self._ticket_price = value
    @property
    def ticket_type(self):
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, value):
        self._ticket_type = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceCityfacilitatorVoucherConfirmResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'end_station' in response:
            self.end_station = response['end_station']
        if 'end_station_name' in response:
            self.end_station_name = response['end_station_name']
        if 'quantity' in response:
            self.quantity = response['quantity']
        if 'start_station' in response:
            self.start_station = response['start_station']
        if 'start_station_name' in response:
            self.start_station_name = response['start_station_name']
        if 'status' in response:
            self.status = response['status']
        if 'ticket_price' in response:
            self.ticket_price = response['ticket_price']
        if 'ticket_type' in response:
            self.ticket_type = response['ticket_type']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PayerPaymentDTO(object):

    def __init__(self):
        self._account_name = None
        self._account_no = None
        self._inst_name = None
        self._pay_tool_type = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value
    @property
    def pay_tool_type(self):
        return self._pay_tool_type

    @pay_tool_type.setter
    def pay_tool_type(self, value):
        self._pay_tool_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.inst_name:
            if hasattr(self.inst_name, 'to_alipay_dict'):
                params['inst_name'] = self.inst_name.to_alipay_dict()
            else:
                params['inst_name'] = self.inst_name
        if self.pay_tool_type:
            if hasattr(self.pay_tool_type, 'to_alipay_dict'):
                params['pay_tool_type'] = self.pay_tool_type.to_alipay_dict()
            else:
                params['pay_tool_type'] = self.pay_tool_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PayerPaymentDTO()
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'inst_name' in d:
            o.inst_name = d['inst_name']
        if 'pay_tool_type' in d:
            o.pay_tool_type = d['pay_tool_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppIndustryPerformOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppIndustryPerformOrderQueryResponse, self).__init__()
        self._bill_amount = None
        self._bill_no = None
        self._chargeoff_status = None
        self._gmt_chargeoff_finish = None
        self._gmt_chargeoff_start = None
        self._gmt_pay = None
        self._gmt_refund = None
        self._gmt_settle = None
        self._inst_code = None
        self._inst_group = None
        self._item_id = None
        self._out_no = None
        self._pay_amount = None
        self._service_code = None
        self._settle_status = None
        self._status = None
        self._trade_no = None

    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def chargeoff_status(self):
        return self._chargeoff_status

    @chargeoff_status.setter
    def chargeoff_status(self, value):
        self._chargeoff_status = value
    @property
    def gmt_chargeoff_finish(self):
        return self._gmt_chargeoff_finish

    @gmt_chargeoff_finish.setter
    def gmt_chargeoff_finish(self, value):
        self._gmt_chargeoff_finish = value
    @property
    def gmt_chargeoff_start(self):
        return self._gmt_chargeoff_start

    @gmt_chargeoff_start.setter
    def gmt_chargeoff_start(self, value):
        self._gmt_chargeoff_start = value
    @property
    def gmt_pay(self):
        return self._gmt_pay

    @gmt_pay.setter
    def gmt_pay(self, value):
        self._gmt_pay = value
    @property
    def gmt_refund(self):
        return self._gmt_refund

    @gmt_refund.setter
    def gmt_refund(self, value):
        self._gmt_refund = value
    @property
    def gmt_settle(self):
        return self._gmt_settle

    @gmt_settle.setter
    def gmt_settle(self, value):
        self._gmt_settle = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def inst_group(self):
        return self._inst_group

    @inst_group.setter
    def inst_group(self, value):
        self._inst_group = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def out_no(self):
        return self._out_no

    @out_no.setter
    def out_no(self, value):
        self._out_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def settle_status(self):
        return self._settle_status

    @settle_status.setter
    def settle_status(self, value):
        self._settle_status = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppIndustryPerformOrderQueryResponse, self).parse_response_content(response_content)
        if 'bill_amount' in response:
            self.bill_amount = response['bill_amount']
        if 'bill_no' in response:
            self.bill_no = response['bill_no']
        if 'chargeoff_status' in response:
            self.chargeoff_status = response['chargeoff_status']
        if 'gmt_chargeoff_finish' in response:
            self.gmt_chargeoff_finish = response['gmt_chargeoff_finish']
        if 'gmt_chargeoff_start' in response:
            self.gmt_chargeoff_start = response['gmt_chargeoff_start']
        if 'gmt_pay' in response:
            self.gmt_pay = response['gmt_pay']
        if 'gmt_refund' in response:
            self.gmt_refund = response['gmt_refund']
        if 'gmt_settle' in response:
            self.gmt_settle = response['gmt_settle']
        if 'inst_code' in response:
            self.inst_code = response['inst_code']
        if 'inst_group' in response:
            self.inst_group = response['inst_group']
        if 'item_id' in response:
            self.item_id = response['item_id']
        if 'out_no' in response:
            self.out_no = response['out_no']
        if 'pay_amount' in response:
            self.pay_amount = response['pay_amount']
        if 'service_code' in response:
            self.service_code = response['service_code']
        if 'settle_status' in response:
            self.settle_status = response['settle_status']
        if 'status' in response:
            self.status = response['status']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceEnterpriseconsumeEnterpriseopenruleCreateModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._bill_month_day = None
        self._enterprise_id = None
        self._invoice_rule_name = None
        self._invoice_title_id = None
        self._open_mode = None
        self._seller_type = None
        self._tag = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def bill_month_day(self):
        return self._bill_month_day

    @bill_month_day.setter
    def bill_month_day(self, value):
        self._bill_month_day = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def invoice_rule_name(self):
        return self._invoice_rule_name

    @invoice_rule_name.setter
    def invoice_rule_name(self, value):
        self._invoice_rule_name = value
    @property
    def invoice_title_id(self):
        return self._invoice_title_id

    @invoice_title_id.setter
    def invoice_title_id(self, value):
        self._invoice_title_id = value
    @property
    def open_mode(self):
        return self._open_mode

    @open_mode.setter
    def open_mode(self, value):
        self._open_mode = value
    @property
    def seller_type(self):
        return self._seller_type

    @seller_type.setter
    def seller_type(self, value):
        self._seller_type = value
    @property
    def tag(self):
        return self._tag

    @tag.setter
    def tag(self, value):
        self._tag = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.bill_month_day:
            if hasattr(self.bill_month_day, 'to_alipay_dict'):
                params['bill_month_day'] = self.bill_month_day.to_alipay_dict()
            else:
                params['bill_month_day'] = self.bill_month_day
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.invoice_rule_name:
            if hasattr(self.invoice_rule_name, 'to_alipay_dict'):
                params['invoice_rule_name'] = self.invoice_rule_name.to_alipay_dict()
            else:
                params['invoice_rule_name'] = self.invoice_rule_name
        if self.invoice_title_id:
            if hasattr(self.invoice_title_id, 'to_alipay_dict'):
                params['invoice_title_id'] = self.invoice_title_id.to_alipay_dict()
            else:
                params['invoice_title_id'] = self.invoice_title_id
        if self.open_mode:
            if hasattr(self.open_mode, 'to_alipay_dict'):
                params['open_mode'] = self.open_mode.to_alipay_dict()
            else:
                params['open_mode'] = self.open_mode
        if self.seller_type:
            if hasattr(self.seller_type, 'to_alipay_dict'):
                params['seller_type'] = self.seller_type.to_alipay_dict()
            else:
                params['seller_type'] = self.seller_type
        if self.tag:
            if hasattr(self.tag, 'to_alipay_dict'):
                params['tag'] = self.tag.to_alipay_dict()
            else:
                params['tag'] = self.tag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceEnterpriseconsumeEnterpriseopenruleCreateModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'bill_month_day' in d:
            o.bill_month_day = d['bill_month_day']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'invoice_rule_name' in d:
            o.invoice_rule_name = d['invoice_rule_name']
        if 'invoice_title_id' in d:
            o.invoice_title_id = d['invoice_title_id']
        if 'open_mode' in d:
            o.open_mode = d['open_mode']
        if 'seller_type' in d:
            o.seller_type = d['seller_type']
        if 'tag' in d:
            o.tag = d['tag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechOceanbasePassaccountBatchqueryModel(object):

    def __init__(self):
        self._account_names = None
        self._passport_ids = None

    @property
    def account_names(self):
        return self._account_names

    @account_names.setter
    def account_names(self, value):
        if isinstance(value, list):
            self._account_names = list()
            for i in value:
                self._account_names.append(i)
    @property
    def passport_ids(self):
        return self._passport_ids

    @passport_ids.setter
    def passport_ids(self, value):
        if isinstance(value, list):
            self._passport_ids = list()
            for i in value:
                self._passport_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.account_names:
            if isinstance(self.account_names, list):
                for i in range(0, len(self.account_names)):
                    element = self.account_names[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.account_names[i] = element.to_alipay_dict()
            if hasattr(self.account_names, 'to_alipay_dict'):
                params['account_names'] = self.account_names.to_alipay_dict()
            else:
                params['account_names'] = self.account_names
        if self.passport_ids:
            if isinstance(self.passport_ids, list):
                for i in range(0, len(self.passport_ids)):
                    element = self.passport_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.passport_ids[i] = element.to_alipay_dict()
            if hasattr(self.passport_ids, 'to_alipay_dict'):
                params['passport_ids'] = self.passport_ids.to_alipay_dict()
            else:
                params['passport_ids'] = self.passport_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechOceanbasePassaccountBatchqueryModel()
        if 'account_names' in d:
            o.account_names = d['account_names']
        if 'passport_ids' in d:
            o.passport_ids = d['passport_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreateExtInfo import CreateExtInfo


class ZhimaCreditEpCreditlinkCollectCreateModel(object):

    def __init__(self):
        self._data_type = None
        self._ep_cert_no = None
        self._ep_name = None
        self._ext_info = None
        self._merchant_request_id = None

    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value
    @property
    def ep_cert_no(self):
        return self._ep_cert_no

    @ep_cert_no.setter
    def ep_cert_no(self, value):
        self._ep_cert_no = value
    @property
    def ep_name(self):
        return self._ep_name

    @ep_name.setter
    def ep_name(self, value):
        self._ep_name = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, CreateExtInfo):
            self._ext_info = value
        else:
            self._ext_info = CreateExtInfo.from_alipay_dict(value)
    @property
    def merchant_request_id(self):
        return self._merchant_request_id

    @merchant_request_id.setter
    def merchant_request_id(self, value):
        self._merchant_request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_type:
            if hasattr(self.data_type, 'to_alipay_dict'):
                params['data_type'] = self.data_type.to_alipay_dict()
            else:
                params['data_type'] = self.data_type
        if self.ep_cert_no:
            if hasattr(self.ep_cert_no, 'to_alipay_dict'):
                params['ep_cert_no'] = self.ep_cert_no.to_alipay_dict()
            else:
                params['ep_cert_no'] = self.ep_cert_no
        if self.ep_name:
            if hasattr(self.ep_name, 'to_alipay_dict'):
                params['ep_name'] = self.ep_name.to_alipay_dict()
            else:
                params['ep_name'] = self.ep_name
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.merchant_request_id:
            if hasattr(self.merchant_request_id, 'to_alipay_dict'):
                params['merchant_request_id'] = self.merchant_request_id.to_alipay_dict()
            else:
                params['merchant_request_id'] = self.merchant_request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpCreditlinkCollectCreateModel()
        if 'data_type' in d:
            o.data_type = d['data_type']
        if 'ep_cert_no' in d:
            o.ep_cert_no = d['ep_cert_no']
        if 'ep_name' in d:
            o.ep_name = d['ep_name']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'merchant_request_id' in d:
            o.merchant_request_id = d['merchant_request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CrowdSummary import CrowdSummary


class AlipayOpenPublicCrowdInnerQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicCrowdInnerQueryResponse, self).__init__()
        self._crowd_summary = None

    @property
    def crowd_summary(self):
        return self._crowd_summary

    @crowd_summary.setter
    def crowd_summary(self, value):
        if isinstance(value, CrowdSummary):
            self._crowd_summary = value
        else:
            self._crowd_summary = CrowdSummary.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicCrowdInnerQueryResponse, self).parse_response_content(response_content)
        if 'crowd_summary' in response:
            self.crowd_summary = response['crowd_summary']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ArticleAttachmentInfo import ArticleAttachmentInfo
from alipay.aop.api.domain.ArticleCategoryInfo import ArticleCategoryInfo
from alipay.aop.api.domain.ArticleAttachmentInfo import ArticleAttachmentInfo


class ArticleInfo(object):

    def __init__(self):
        self._attachments = None
        self._category_id = None
        self._category_name_path = None
        self._category_path = None
        self._content = None
        self._create_time = None
        self._creator_id = None
        self._extend_titles = None
        self._id = None
        self._keywords = None
        self._library_id = None
        self._order_no = None
        self._pictures = None
        self._publish_end = None
        self._publish_start = None
        self._scene_codes = None
        self._source = None
        self._status = None
        self._status_code = None
        self._title = None
        self._update_time = None
        self._updater_id = None
        self._updater_name = None

    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, list):
            self._attachments = list()
            for i in value:
                if isinstance(i, ArticleAttachmentInfo):
                    self._attachments.append(i)
                else:
                    self._attachments.append(ArticleAttachmentInfo.from_alipay_dict(i))
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def category_name_path(self):
        return self._category_name_path

    @category_name_path.setter
    def category_name_path(self, value):
        self._category_name_path = value
    @property
    def category_path(self):
        return self._category_path

    @category_path.setter
    def category_path(self, value):
        if isinstance(value, list):
            self._category_path = list()
            for i in value:
                if isinstance(i, ArticleCategoryInfo):
                    self._category_path.append(i)
                else:
                    self._category_path.append(ArticleCategoryInfo.from_alipay_dict(i))
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def extend_titles(self):
        return self._extend_titles

    @extend_titles.setter
    def extend_titles(self, value):
        if isinstance(value, list):
            self._extend_titles = list()
            for i in value:
                self._extend_titles.append(i)
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def keywords(self):
        return self._keywords

    @keywords.setter
    def keywords(self, value):
        if isinstance(value, list):
            self._keywords = list()
            for i in value:
                self._keywords.append(i)
    @property
    def library_id(self):
        return self._library_id

    @library_id.setter
    def library_id(self, value):
        self._library_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def pictures(self):
        return self._pictures

    @pictures.setter
    def pictures(self, value):
        if isinstance(value, list):
            self._pictures = list()
            for i in value:
                if isinstance(i, ArticleAttachmentInfo):
                    self._pictures.append(i)
                else:
                    self._pictures.append(ArticleAttachmentInfo.from_alipay_dict(i))
    @property
    def publish_end(self):
        return self._publish_end

    @publish_end.setter
    def publish_end(self, value):
        self._publish_end = value
    @property
    def publish_start(self):
        return self._publish_start

    @publish_start.setter
    def publish_start(self, value):
        self._publish_start = value
    @property
    def scene_codes(self):
        return self._scene_codes

    @scene_codes.setter
    def scene_codes(self, value):
        if isinstance(value, list):
            self._scene_codes = list()
            for i in value:
                self._scene_codes.append(i)
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def status_code(self):
        return self._status_code

    @status_code.setter
    def status_code(self, value):
        self._status_code = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value
    @property
    def updater_id(self):
        return self._updater_id

    @updater_id.setter
    def updater_id(self, value):
        self._updater_id = value
    @property
    def updater_name(self):
        return self._updater_name

    @updater_name.setter
    def updater_name(self, value):
        self._updater_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.attachments:
            if isinstance(self.attachments, list):
                for i in range(0, len(self.attachments)):
                    element = self.attachments[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachments[i] = element.to_alipay_dict()
            if hasattr(self.attachments, 'to_alipay_dict'):
                params['attachments'] = self.attachments.to_alipay_dict()
            else:
                params['attachments'] = self.attachments
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.category_name_path:
            if hasattr(self.category_name_path, 'to_alipay_dict'):
                params['category_name_path'] = self.category_name_path.to_alipay_dict()
            else:
                params['category_name_path'] = self.category_name_path
        if self.category_path:
            if isinstance(self.category_path, list):
                for i in range(0, len(self.category_path)):
                    element = self.category_path[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.category_path[i] = element.to_alipay_dict()
            if hasattr(self.category_path, 'to_alipay_dict'):
                params['category_path'] = self.category_path.to_alipay_dict()
            else:
                params['category_path'] = self.category_path
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.extend_titles:
            if isinstance(self.extend_titles, list):
                for i in range(0, len(self.extend_titles)):
                    element = self.extend_titles[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.extend_titles[i] = element.to_alipay_dict()
            if hasattr(self.extend_titles, 'to_alipay_dict'):
                params['extend_titles'] = self.extend_titles.to_alipay_dict()
            else:
                params['extend_titles'] = self.extend_titles
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.keywords:
            if isinstance(self.keywords, list):
                for i in range(0, len(self.keywords)):
                    element = self.keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.keywords[i] = element.to_alipay_dict()
            if hasattr(self.keywords, 'to_alipay_dict'):
                params['keywords'] = self.keywords.to_alipay_dict()
            else:
                params['keywords'] = self.keywords
        if self.library_id:
            if hasattr(self.library_id, 'to_alipay_dict'):
                params['library_id'] = self.library_id.to_alipay_dict()
            else:
                params['library_id'] = self.library_id
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.pictures:
            if isinstance(self.pictures, list):
                for i in range(0, len(self.pictures)):
                    element = self.pictures[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pictures[i] = element.to_alipay_dict()
            if hasattr(self.pictures, 'to_alipay_dict'):
                params['pictures'] = self.pictures.to_alipay_dict()
            else:
                params['pictures'] = self.pictures
        if self.publish_end:
            if hasattr(self.publish_end, 'to_alipay_dict'):
                params['publish_end'] = self.publish_end.to_alipay_dict()
            else:
                params['publish_end'] = self.publish_end
        if self.publish_start:
            if hasattr(self.publish_start, 'to_alipay_dict'):
                params['publish_start'] = self.publish_start.to_alipay_dict()
            else:
                params['publish_start'] = self.publish_start
        if self.scene_codes:
            if isinstance(self.scene_codes, list):
                for i in range(0, len(self.scene_codes)):
                    element = self.scene_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.scene_codes[i] = element.to_alipay_dict()
            if hasattr(self.scene_codes, 'to_alipay_dict'):
                params['scene_codes'] = self.scene_codes.to_alipay_dict()
            else:
                params['scene_codes'] = self.scene_codes
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.status_code:
            if hasattr(self.status_code, 'to_alipay_dict'):
                params['status_code'] = self.status_code.to_alipay_dict()
            else:
                params['status_code'] = self.status_code
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.update_time:
            if hasattr(self.update_time, 'to_alipay_dict'):
                params['update_time'] = self.update_time.to_alipay_dict()
            else:
                params['update_time'] = self.update_time
        if self.updater_id:
            if hasattr(self.updater_id, 'to_alipay_dict'):
                params['updater_id'] = self.updater_id.to_alipay_dict()
            else:
                params['updater_id'] = self.updater_id
        if self.updater_name:
            if hasattr(self.updater_name, 'to_alipay_dict'):
                params['updater_name'] = self.updater_name.to_alipay_dict()
            else:
                params['updater_name'] = self.updater_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ArticleInfo()
        if 'attachments' in d:
            o.attachments = d['attachments']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'category_name_path' in d:
            o.category_name_path = d['category_name_path']
        if 'category_path' in d:
            o.category_path = d['category_path']
        if 'content' in d:
            o.content = d['content']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'extend_titles' in d:
            o.extend_titles = d['extend_titles']
        if 'id' in d:
            o.id = d['id']
        if 'keywords' in d:
            o.keywords = d['keywords']
        if 'library_id' in d:
            o.library_id = d['library_id']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'pictures' in d:
            o.pictures = d['pictures']
        if 'publish_end' in d:
            o.publish_end = d['publish_end']
        if 'publish_start' in d:
            o.publish_start = d['publish_start']
        if 'scene_codes' in d:
            o.scene_codes = d['scene_codes']
        if 'source' in d:
            o.source = d['source']
        if 'status' in d:
            o.status = d['status']
        if 'status_code' in d:
            o.status_code = d['status_code']
        if 'title' in d:
            o.title = d['title']
        if 'update_time' in d:
            o.update_time = d['update_time']
        if 'updater_id' in d:
            o.updater_id = d['updater_id']
        if 'updater_name' in d:
            o.updater_name = d['updater_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ArrangementConditionGroupSelector(object):

    def __init__(self):
        self._select_latest_pd_cd = None

    @property
    def select_latest_pd_cd(self):
        return self._select_latest_pd_cd

    @select_latest_pd_cd.setter
    def select_latest_pd_cd(self, value):
        self._select_latest_pd_cd = value


    def to_alipay_dict(self):
        params = dict()
        if self.select_latest_pd_cd:
            if hasattr(self.select_latest_pd_cd, 'to_alipay_dict'):
                params['select_latest_pd_cd'] = self.select_latest_pd_cd.to_alipay_dict()
            else:
                params['select_latest_pd_cd'] = self.select_latest_pd_cd
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ArrangementConditionGroupSelector()
        if 'select_latest_pd_cd' in d:
            o.select_latest_pd_cd = d['select_latest_pd_cd']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ObjRsDataDTO import ObjRsDataDTO
from alipay.aop.api.domain.Status import Status


class AntfortuneQuotationNimitzDatasetQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntfortuneQuotationNimitzDatasetQueryResponse, self).__init__()
        self._result = None
        self._result_data = None
        self._result_status = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, list):
            self._result_data = list()
            for i in value:
                if isinstance(i, ObjRsDataDTO):
                    self._result_data.append(i)
                else:
                    self._result_data.append(ObjRsDataDTO.from_alipay_dict(i))
    @property
    def result_status(self):
        return self._result_status

    @result_status.setter
    def result_status(self, value):
        if isinstance(value, Status):
            self._result_status = value
        else:
            self._result_status = Status.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AntfortuneQuotationNimitzDatasetQueryResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']
        if 'result_data' in response:
            self.result_data = response['result_data']
        if 'result_status' in response:
            self.result_status = response['result_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoCplifeCommunityModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCplifeCommunityModifyResponse, self).__init__()
        self._next_action = None
        self._status = None

    @property
    def next_action(self):
        return self._next_action

    @next_action.setter
    def next_action(self, value):
        self._next_action = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCplifeCommunityModifyResponse, self).parse_response_content(response_content)
        if 'next_action' in response:
            self.next_action = response['next_action']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FundBankCardInfoDTO import FundBankCardInfoDTO
from alipay.aop.api.domain.WithholdAgreementInfoDTO import WithholdAgreementInfoDTO


class AlipayCommerceFundBindQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceFundBindQueryResponse, self).__init__()
        self._bank_card_info = None
        self._bind_error_code = None
        self._bind_error_msg = None
        self._cert_no = None
        self._cert_type = None
        self._open_id = None
        self._out_bind_no = None
        self._real_name = None
        self._status = None
        self._user_id = None
        self._withhold_agreement_info = None

    @property
    def bank_card_info(self):
        return self._bank_card_info

    @bank_card_info.setter
    def bank_card_info(self, value):
        if isinstance(value, FundBankCardInfoDTO):
            self._bank_card_info = value
        else:
            self._bank_card_info = FundBankCardInfoDTO.from_alipay_dict(value)
    @property
    def bind_error_code(self):
        return self._bind_error_code

    @bind_error_code.setter
    def bind_error_code(self, value):
        self._bind_error_code = value
    @property
    def bind_error_msg(self):
        return self._bind_error_msg

    @bind_error_msg.setter
    def bind_error_msg(self, value):
        self._bind_error_msg = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_bind_no(self):
        return self._out_bind_no

    @out_bind_no.setter
    def out_bind_no(self, value):
        self._out_bind_no = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def withhold_agreement_info(self):
        return self._withhold_agreement_info

    @withhold_agreement_info.setter
    def withhold_agreement_info(self, value):
        if isinstance(value, WithholdAgreementInfoDTO):
            self._withhold_agreement_info = value
        else:
            self._withhold_agreement_info = WithholdAgreementInfoDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceFundBindQueryResponse, self).parse_response_content(response_content)
        if 'bank_card_info' in response:
            self.bank_card_info = response['bank_card_info']
        if 'bind_error_code' in response:
            self.bind_error_code = response['bind_error_code']
        if 'bind_error_msg' in response:
            self.bind_error_msg = response['bind_error_msg']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_type' in response:
            self.cert_type = response['cert_type']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_bind_no' in response:
            self.out_bind_no = response['out_bind_no']
        if 'real_name' in response:
            self.real_name = response['real_name']
        if 'status' in response:
            self.status = response['status']
        if 'user_id' in response:
            self.user_id = response['user_id']
        if 'withhold_agreement_info' in response:
            self.withhold_agreement_info = response['withhold_agreement_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserMpointQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserMpointQueryResponse, self).__init__()
        self._balance = None
        self._grade = None
        self._joint_info = None

    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def grade(self):
        return self._grade

    @grade.setter
    def grade(self, value):
        self._grade = value
    @property
    def joint_info(self):
        return self._joint_info

    @joint_info.setter
    def joint_info(self, value):
        if isinstance(value, list):
            self._joint_info = list()
            for i in value:
                self._joint_info.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayUserMpointQueryResponse, self).parse_response_content(response_content)
        if 'balance' in response:
            self.balance = response['balance']
        if 'grade' in response:
            self.grade = response['grade']
        if 'joint_info' in response:
            self.joint_info = response['joint_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasTravelContentCancelModel(object):

    def __init__(self):
        self._content_id = None
        self._modified_date = None

    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def modified_date(self):
        return self._modified_date

    @modified_date.setter
    def modified_date(self, value):
        self._modified_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.modified_date:
            if hasattr(self.modified_date, 'to_alipay_dict'):
                params['modified_date'] = self.modified_date.to_alipay_dict()
            else:
                params['modified_date'] = self.modified_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelContentCancelModel()
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'modified_date' in d:
            o.modified_date = d['modified_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingCampaignRuleTagQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCampaignRuleTagQueryResponse, self).__init__()
        self._customtagjson = None
        self._scenetagjson = None

    @property
    def customtagjson(self):
        return self._customtagjson

    @customtagjson.setter
    def customtagjson(self, value):
        self._customtagjson = value
    @property
    def scenetagjson(self):
        return self._scenetagjson

    @scenetagjson.setter
    def scenetagjson(self, value):
        self._scenetagjson = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCampaignRuleTagQueryResponse, self).parse_response_content(response_content)
        if 'customtagjson' in response:
            self.customtagjson = response['customtagjson']
        if 'scenetagjson' in response:
            self.scenetagjson = response['scenetagjson']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AssetFundInfo(object):

    def __init__(self):
        self._amount = None
        self._fund_account = None
        self._fund_type = None
        self._settle_dead_line = None
        self._settle_mode = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def fund_account(self):
        return self._fund_account

    @fund_account.setter
    def fund_account(self, value):
        self._fund_account = value
    @property
    def fund_type(self):
        return self._fund_type

    @fund_type.setter
    def fund_type(self, value):
        self._fund_type = value
    @property
    def settle_dead_line(self):
        return self._settle_dead_line

    @settle_dead_line.setter
    def settle_dead_line(self, value):
        self._settle_dead_line = value
    @property
    def settle_mode(self):
        return self._settle_mode

    @settle_mode.setter
    def settle_mode(self, value):
        self._settle_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.fund_account:
            if hasattr(self.fund_account, 'to_alipay_dict'):
                params['fund_account'] = self.fund_account.to_alipay_dict()
            else:
                params['fund_account'] = self.fund_account
        if self.fund_type:
            if hasattr(self.fund_type, 'to_alipay_dict'):
                params['fund_type'] = self.fund_type.to_alipay_dict()
            else:
                params['fund_type'] = self.fund_type
        if self.settle_dead_line:
            if hasattr(self.settle_dead_line, 'to_alipay_dict'):
                params['settle_dead_line'] = self.settle_dead_line.to_alipay_dict()
            else:
                params['settle_dead_line'] = self.settle_dead_line
        if self.settle_mode:
            if hasattr(self.settle_mode, 'to_alipay_dict'):
                params['settle_mode'] = self.settle_mode.to_alipay_dict()
            else:
                params['settle_mode'] = self.settle_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AssetFundInfo()
        if 'amount' in d:
            o.amount = d['amount']
        if 'fund_account' in d:
            o.fund_account = d['fund_account']
        if 'fund_type' in d:
            o.fund_type = d['fund_type']
        if 'settle_dead_line' in d:
            o.settle_dead_line = d['settle_dead_line']
        if 'settle_mode' in d:
            o.settle_mode = d['settle_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class WitnessPrincipalDTO(object):

    def __init__(self):
        self._account_no = None
        self._principal_id = None
        self._principal_type = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def principal_type(self):
        return self._principal_type

    @principal_type.setter
    def principal_type(self, value):
        self._principal_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.principal_type:
            if hasattr(self.principal_type, 'to_alipay_dict'):
                params['principal_type'] = self.principal_type.to_alipay_dict()
            else:
                params['principal_type'] = self.principal_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WitnessPrincipalDTO()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'principal_type' in d:
            o.principal_type = d['principal_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeliverySingleMaterial(object):

    def __init__(self):
        self._delivery_image = None

    @property
    def delivery_image(self):
        return self._delivery_image

    @delivery_image.setter
    def delivery_image(self, value):
        self._delivery_image = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_image:
            if hasattr(self.delivery_image, 'to_alipay_dict'):
                params['delivery_image'] = self.delivery_image.to_alipay_dict()
            else:
                params['delivery_image'] = self.delivery_image
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliverySingleMaterial()
        if 'delivery_image' in d:
            o.delivery_image = d['delivery_image']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InstAllocationQuotaVO(object):

    def __init__(self):
        self._account_no = None
        self._account_type = None
        self._active = None
        self._effective_time = None
        self._expire_time = None
        self._memo = None
        self._quota_mode = None
        self._quota_value = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def active(self):
        return self._active

    @active.setter
    def active(self, value):
        self._active = value
    @property
    def effective_time(self):
        return self._effective_time

    @effective_time.setter
    def effective_time(self, value):
        self._effective_time = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def quota_mode(self):
        return self._quota_mode

    @quota_mode.setter
    def quota_mode(self, value):
        self._quota_mode = value
    @property
    def quota_value(self):
        return self._quota_value

    @quota_value.setter
    def quota_value(self, value):
        self._quota_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.active:
            if hasattr(self.active, 'to_alipay_dict'):
                params['active'] = self.active.to_alipay_dict()
            else:
                params['active'] = self.active
        if self.effective_time:
            if hasattr(self.effective_time, 'to_alipay_dict'):
                params['effective_time'] = self.effective_time.to_alipay_dict()
            else:
                params['effective_time'] = self.effective_time
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.quota_mode:
            if hasattr(self.quota_mode, 'to_alipay_dict'):
                params['quota_mode'] = self.quota_mode.to_alipay_dict()
            else:
                params['quota_mode'] = self.quota_mode
        if self.quota_value:
            if hasattr(self.quota_value, 'to_alipay_dict'):
                params['quota_value'] = self.quota_value.to_alipay_dict()
            else:
                params['quota_value'] = self.quota_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstAllocationQuotaVO()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'active' in d:
            o.active = d['active']
        if 'effective_time' in d:
            o.effective_time = d['effective_time']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'memo' in d:
            o.memo = d['memo']
        if 'quota_mode' in d:
            o.quota_mode = d['quota_mode']
        if 'quota_value' in d:
            o.quota_value = d['quota_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotvspOrguserDeleteModel(object):

    def __init__(self):
        self._entity_id = None
        self._entity_type = None
        self._face_id = None
        self._group_id = None
        self._isv_app_id = None
        self._isv_name = None
        self._isv_pid = None

    @property
    def entity_id(self):
        return self._entity_id

    @entity_id.setter
    def entity_id(self, value):
        self._entity_id = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value
    @property
    def face_id(self):
        return self._face_id

    @face_id.setter
    def face_id(self, value):
        self._face_id = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def isv_app_id(self):
        return self._isv_app_id

    @isv_app_id.setter
    def isv_app_id(self, value):
        self._isv_app_id = value
    @property
    def isv_name(self):
        return self._isv_name

    @isv_name.setter
    def isv_name(self, value):
        self._isv_name = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.entity_id:
            if hasattr(self.entity_id, 'to_alipay_dict'):
                params['entity_id'] = self.entity_id.to_alipay_dict()
            else:
                params['entity_id'] = self.entity_id
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        if self.face_id:
            if hasattr(self.face_id, 'to_alipay_dict'):
                params['face_id'] = self.face_id.to_alipay_dict()
            else:
                params['face_id'] = self.face_id
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.isv_app_id:
            if hasattr(self.isv_app_id, 'to_alipay_dict'):
                params['isv_app_id'] = self.isv_app_id.to_alipay_dict()
            else:
                params['isv_app_id'] = self.isv_app_id
        if self.isv_name:
            if hasattr(self.isv_name, 'to_alipay_dict'):
                params['isv_name'] = self.isv_name.to_alipay_dict()
            else:
                params['isv_name'] = self.isv_name
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotvspOrguserDeleteModel()
        if 'entity_id' in d:
            o.entity_id = d['entity_id']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        if 'face_id' in d:
            o.face_id = d['face_id']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'isv_app_id' in d:
            o.isv_app_id = d['isv_app_id']
        if 'isv_name' in d:
            o.isv_name = d['isv_name']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BoxExclusiveServiceData(object):

    def __init__(self):
        self._serv_code = None
        self._serv_desc = None
        self._serv_id = None
        self._serv_link = None
        self._serv_logo = None
        self._serv_name = None

    @property
    def serv_code(self):
        return self._serv_code

    @serv_code.setter
    def serv_code(self, value):
        self._serv_code = value
    @property
    def serv_desc(self):
        return self._serv_desc

    @serv_desc.setter
    def serv_desc(self, value):
        self._serv_desc = value
    @property
    def serv_id(self):
        return self._serv_id

    @serv_id.setter
    def serv_id(self, value):
        self._serv_id = value
    @property
    def serv_link(self):
        return self._serv_link

    @serv_link.setter
    def serv_link(self, value):
        self._serv_link = value
    @property
    def serv_logo(self):
        return self._serv_logo

    @serv_logo.setter
    def serv_logo(self, value):
        self._serv_logo = value
    @property
    def serv_name(self):
        return self._serv_name

    @serv_name.setter
    def serv_name(self, value):
        self._serv_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.serv_code:
            if hasattr(self.serv_code, 'to_alipay_dict'):
                params['serv_code'] = self.serv_code.to_alipay_dict()
            else:
                params['serv_code'] = self.serv_code
        if self.serv_desc:
            if hasattr(self.serv_desc, 'to_alipay_dict'):
                params['serv_desc'] = self.serv_desc.to_alipay_dict()
            else:
                params['serv_desc'] = self.serv_desc
        if self.serv_id:
            if hasattr(self.serv_id, 'to_alipay_dict'):
                params['serv_id'] = self.serv_id.to_alipay_dict()
            else:
                params['serv_id'] = self.serv_id
        if self.serv_link:
            if hasattr(self.serv_link, 'to_alipay_dict'):
                params['serv_link'] = self.serv_link.to_alipay_dict()
            else:
                params['serv_link'] = self.serv_link
        if self.serv_logo:
            if hasattr(self.serv_logo, 'to_alipay_dict'):
                params['serv_logo'] = self.serv_logo.to_alipay_dict()
            else:
                params['serv_logo'] = self.serv_logo
        if self.serv_name:
            if hasattr(self.serv_name, 'to_alipay_dict'):
                params['serv_name'] = self.serv_name.to_alipay_dict()
            else:
                params['serv_name'] = self.serv_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BoxExclusiveServiceData()
        if 'serv_code' in d:
            o.serv_code = d['serv_code']
        if 'serv_desc' in d:
            o.serv_desc = d['serv_desc']
        if 'serv_id' in d:
            o.serv_id = d['serv_id']
        if 'serv_link' in d:
            o.serv_link = d['serv_link']
        if 'serv_logo' in d:
            o.serv_logo = d['serv_logo']
        if 'serv_name' in d:
            o.serv_name = d['serv_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CropsStatisticsInfo(object):

    def __init__(self):
        self._addition_info = None
        self._crop_code = None
        self._drought_risk_plot_count = None
        self._estimate_harvest_time_max = None
        self._estimate_harvest_time_min = None
        self._growth_general_area_sum = None
        self._growth_general_plot_count = None
        self._growth_stronger_area_sum = None
        self._growth_stronger_plot_count = None
        self._growth_strongest_area_sum = None
        self._growth_strongest_plot_count = None
        self._growth_weaker_area_sum = None
        self._growth_weaker_plot_count = None
        self._growth_weakest_area_sum = None
        self._growth_weakest_plot_count = None
        self._harvest_progress_value = None
        self._harvested_area_sum = None
        self._high_temp_risk_plot_count = None
        self._low_temp_risk_plot_count = None
        self._maturity_plot_count = None
        self._not_harvested_area_sum = None
        self._planting_area_sum = None
        self._plot_area_sum = None
        self._plot_count = None
        self._rainstorm_risk_plot_count = None
        self._region_codes = None
        self._soil_moisture_risk_plot_count = None
        self._total_area_sum = None
        self._total_yield_sum = None

    @property
    def addition_info(self):
        return self._addition_info

    @addition_info.setter
    def addition_info(self, value):
        self._addition_info = value
    @property
    def crop_code(self):
        return self._crop_code

    @crop_code.setter
    def crop_code(self, value):
        self._crop_code = value
    @property
    def drought_risk_plot_count(self):
        return self._drought_risk_plot_count

    @drought_risk_plot_count.setter
    def drought_risk_plot_count(self, value):
        self._drought_risk_plot_count = value
    @property
    def estimate_harvest_time_max(self):
        return self._estimate_harvest_time_max

    @estimate_harvest_time_max.setter
    def estimate_harvest_time_max(self, value):
        self._estimate_harvest_time_max = value
    @property
    def estimate_harvest_time_min(self):
        return self._estimate_harvest_time_min

    @estimate_harvest_time_min.setter
    def estimate_harvest_time_min(self, value):
        self._estimate_harvest_time_min = value
    @property
    def growth_general_area_sum(self):
        return self._growth_general_area_sum

    @growth_general_area_sum.setter
    def growth_general_area_sum(self, value):
        self._growth_general_area_sum = value
    @property
    def growth_general_plot_count(self):
        return self._growth_general_plot_count

    @growth_general_plot_count.setter
    def growth_general_plot_count(self, value):
        self._growth_general_plot_count = value
    @property
    def growth_stronger_area_sum(self):
        return self._growth_stronger_area_sum

    @growth_stronger_area_sum.setter
    def growth_stronger_area_sum(self, value):
        self._growth_stronger_area_sum = value
    @property
    def growth_stronger_plot_count(self):
        return self._growth_stronger_plot_count

    @growth_stronger_plot_count.setter
    def growth_stronger_plot_count(self, value):
        self._growth_stronger_plot_count = value
    @property
    def growth_strongest_area_sum(self):
        return self._growth_strongest_area_sum

    @growth_strongest_area_sum.setter
    def growth_strongest_area_sum(self, value):
        self._growth_strongest_area_sum = value
    @property
    def growth_strongest_plot_count(self):
        return self._growth_strongest_plot_count

    @growth_strongest_plot_count.setter
    def growth_strongest_plot_count(self, value):
        self._growth_strongest_plot_count = value
    @property
    def growth_weaker_area_sum(self):
        return self._growth_weaker_area_sum

    @growth_weaker_area_sum.setter
    def growth_weaker_area_sum(self, value):
        self._growth_weaker_area_sum = value
    @property
    def growth_weaker_plot_count(self):
        return self._growth_weaker_plot_count

    @growth_weaker_plot_count.setter
    def growth_weaker_plot_count(self, value):
        self._growth_weaker_plot_count = value
    @property
    def growth_weakest_area_sum(self):
        return self._growth_weakest_area_sum

    @growth_weakest_area_sum.setter
    def growth_weakest_area_sum(self, value):
        self._growth_weakest_area_sum = value
    @property
    def growth_weakest_plot_count(self):
        return self._growth_weakest_plot_count

    @growth_weakest_plot_count.setter
    def growth_weakest_plot_count(self, value):
        self._growth_weakest_plot_count = value
    @property
    def harvest_progress_value(self):
        return self._harvest_progress_value

    @harvest_progress_value.setter
    def harvest_progress_value(self, value):
        self._harvest_progress_value = value
    @property
    def harvested_area_sum(self):
        return self._harvested_area_sum

    @harvested_area_sum.setter
    def harvested_area_sum(self, value):
        self._harvested_area_sum = value
    @property
    def high_temp_risk_plot_count(self):
        return self._high_temp_risk_plot_count

    @high_temp_risk_plot_count.setter
    def high_temp_risk_plot_count(self, value):
        self._high_temp_risk_plot_count = value
    @property
    def low_temp_risk_plot_count(self):
        return self._low_temp_risk_plot_count

    @low_temp_risk_plot_count.setter
    def low_temp_risk_plot_count(self, value):
        self._low_temp_risk_plot_count = value
    @property
    def maturity_plot_count(self):
        return self._maturity_plot_count

    @maturity_plot_count.setter
    def maturity_plot_count(self, value):
        self._maturity_plot_count = value
    @property
    def not_harvested_area_sum(self):
        return self._not_harvested_area_sum

    @not_harvested_area_sum.setter
    def not_harvested_area_sum(self, value):
        self._not_harvested_area_sum = value
    @property
    def planting_area_sum(self):
        return self._planting_area_sum

    @planting_area_sum.setter
    def planting_area_sum(self, value):
        self._planting_area_sum = value
    @property
    def plot_area_sum(self):
        return self._plot_area_sum

    @plot_area_sum.setter
    def plot_area_sum(self, value):
        self._plot_area_sum = value
    @property
    def plot_count(self):
        return self._plot_count

    @plot_count.setter
    def plot_count(self, value):
        self._plot_count = value
    @property
    def rainstorm_risk_plot_count(self):
        return self._rainstorm_risk_plot_count

    @rainstorm_risk_plot_count.setter
    def rainstorm_risk_plot_count(self, value):
        self._rainstorm_risk_plot_count = value
    @property
    def region_codes(self):
        return self._region_codes

    @region_codes.setter
    def region_codes(self, value):
        if isinstance(value, list):
            self._region_codes = list()
            for i in value:
                self._region_codes.append(i)
    @property
    def soil_moisture_risk_plot_count(self):
        return self._soil_moisture_risk_plot_count

    @soil_moisture_risk_plot_count.setter
    def soil_moisture_risk_plot_count(self, value):
        self._soil_moisture_risk_plot_count = value
    @property
    def total_area_sum(self):
        return self._total_area_sum

    @total_area_sum.setter
    def total_area_sum(self, value):
        self._total_area_sum = value
    @property
    def total_yield_sum(self):
        return self._total_yield_sum

    @total_yield_sum.setter
    def total_yield_sum(self, value):
        self._total_yield_sum = value


    def to_alipay_dict(self):
        params = dict()
        if self.addition_info:
            if hasattr(self.addition_info, 'to_alipay_dict'):
                params['addition_info'] = self.addition_info.to_alipay_dict()
            else:
                params['addition_info'] = self.addition_info
        if self.crop_code:
            if hasattr(self.crop_code, 'to_alipay_dict'):
                params['crop_code'] = self.crop_code.to_alipay_dict()
            else:
                params['crop_code'] = self.crop_code
        if self.drought_risk_plot_count:
            if hasattr(self.drought_risk_plot_count, 'to_alipay_dict'):
                params['drought_risk_plot_count'] = self.drought_risk_plot_count.to_alipay_dict()
            else:
                params['drought_risk_plot_count'] = self.drought_risk_plot_count
        if self.estimate_harvest_time_max:
            if hasattr(self.estimate_harvest_time_max, 'to_alipay_dict'):
                params['estimate_harvest_time_max'] = self.estimate_harvest_time_max.to_alipay_dict()
            else:
                params['estimate_harvest_time_max'] = self.estimate_harvest_time_max
        if self.estimate_harvest_time_min:
            if hasattr(self.estimate_harvest_time_min, 'to_alipay_dict'):
                params['estimate_harvest_time_min'] = self.estimate_harvest_time_min.to_alipay_dict()
            else:
                params['estimate_harvest_time_min'] = self.estimate_harvest_time_min
        if self.growth_general_area_sum:
            if hasattr(self.growth_general_area_sum, 'to_alipay_dict'):
                params['growth_general_area_sum'] = self.growth_general_area_sum.to_alipay_dict()
            else:
                params['growth_general_area_sum'] = self.growth_general_area_sum
        if self.growth_general_plot_count:
            if hasattr(self.growth_general_plot_count, 'to_alipay_dict'):
                params['growth_general_plot_count'] = self.growth_general_plot_count.to_alipay_dict()
            else:
                params['growth_general_plot_count'] = self.growth_general_plot_count
        if self.growth_stronger_area_sum:
            if hasattr(self.growth_stronger_area_sum, 'to_alipay_dict'):
                params['growth_stronger_area_sum'] = self.growth_stronger_area_sum.to_alipay_dict()
            else:
                params['growth_stronger_area_sum'] = self.growth_stronger_area_sum
        if self.growth_stronger_plot_count:
            if hasattr(self.growth_stronger_plot_count, 'to_alipay_dict'):
                params['growth_stronger_plot_count'] = self.growth_stronger_plot_count.to_alipay_dict()
            else:
                params['growth_stronger_plot_count'] = self.growth_stronger_plot_count
        if self.growth_strongest_area_sum:
            if hasattr(self.growth_strongest_area_sum, 'to_alipay_dict'):
                params['growth_strongest_area_sum'] = self.growth_strongest_area_sum.to_alipay_dict()
            else:
                params['growth_strongest_area_sum'] = self.growth_strongest_area_sum
        if self.growth_strongest_plot_count:
            if hasattr(self.growth_strongest_plot_count, 'to_alipay_dict'):
                params['growth_strongest_plot_count'] = self.growth_strongest_plot_count.to_alipay_dict()
            else:
                params['growth_strongest_plot_count'] = self.growth_strongest_plot_count
        if self.growth_weaker_area_sum:
            if hasattr(self.growth_weaker_area_sum, 'to_alipay_dict'):
                params['growth_weaker_area_sum'] = self.growth_weaker_area_sum.to_alipay_dict()
            else:
                params['growth_weaker_area_sum'] = self.growth_weaker_area_sum
        if self.growth_weaker_plot_count:
            if hasattr(self.growth_weaker_plot_count, 'to_alipay_dict'):
                params['growth_weaker_plot_count'] = self.growth_weaker_plot_count.to_alipay_dict()
            else:
                params['growth_weaker_plot_count'] = self.growth_weaker_plot_count
        if self.growth_weakest_area_sum:
            if hasattr(self.growth_weakest_area_sum, 'to_alipay_dict'):
                params['growth_weakest_area_sum'] = self.growth_weakest_area_sum.to_alipay_dict()
            else:
                params['growth_weakest_area_sum'] = self.growth_weakest_area_sum
        if self.growth_weakest_plot_count:
            if hasattr(self.growth_weakest_plot_count, 'to_alipay_dict'):
                params['growth_weakest_plot_count'] = self.growth_weakest_plot_count.to_alipay_dict()
            else:
                params['growth_weakest_plot_count'] = self.growth_weakest_plot_count
        if self.harvest_progress_value:
            if hasattr(self.harvest_progress_value, 'to_alipay_dict'):
                params['harvest_progress_value'] = self.harvest_progress_value.to_alipay_dict()
            else:
                params['harvest_progress_value'] = self.harvest_progress_value
        if self.harvested_area_sum:
            if hasattr(self.harvested_area_sum, 'to_alipay_dict'):
                params['harvested_area_sum'] = self.harvested_area_sum.to_alipay_dict()
            else:
                params['harvested_area_sum'] = self.harvested_area_sum
        if self.high_temp_risk_plot_count:
            if hasattr(self.high_temp_risk_plot_count, 'to_alipay_dict'):
                params['high_temp_risk_plot_count'] = self.high_temp_risk_plot_count.to_alipay_dict()
            else:
                params['high_temp_risk_plot_count'] = self.high_temp_risk_plot_count
        if self.low_temp_risk_plot_count:
            if hasattr(self.low_temp_risk_plot_count, 'to_alipay_dict'):
                params['low_temp_risk_plot_count'] = self.low_temp_risk_plot_count.to_alipay_dict()
            else:
                params['low_temp_risk_plot_count'] = self.low_temp_risk_plot_count
        if self.maturity_plot_count:
            if hasattr(self.maturity_plot_count, 'to_alipay_dict'):
                params['maturity_plot_count'] = self.maturity_plot_count.to_alipay_dict()
            else:
                params['maturity_plot_count'] = self.maturity_plot_count
        if self.not_harvested_area_sum:
            if hasattr(self.not_harvested_area_sum, 'to_alipay_dict'):
                params['not_harvested_area_sum'] = self.not_harvested_area_sum.to_alipay_dict()
            else:
                params['not_harvested_area_sum'] = self.not_harvested_area_sum
        if self.planting_area_sum:
            if hasattr(self.planting_area_sum, 'to_alipay_dict'):
                params['planting_area_sum'] = self.planting_area_sum.to_alipay_dict()
            else:
                params['planting_area_sum'] = self.planting_area_sum
        if self.plot_area_sum:
            if hasattr(self.plot_area_sum, 'to_alipay_dict'):
                params['plot_area_sum'] = self.plot_area_sum.to_alipay_dict()
            else:
                params['plot_area_sum'] = self.plot_area_sum
        if self.plot_count:
            if hasattr(self.plot_count, 'to_alipay_dict'):
                params['plot_count'] = self.plot_count.to_alipay_dict()
            else:
                params['plot_count'] = self.plot_count
        if self.rainstorm_risk_plot_count:
            if hasattr(self.rainstorm_risk_plot_count, 'to_alipay_dict'):
                params['rainstorm_risk_plot_count'] = self.rainstorm_risk_plot_count.to_alipay_dict()
            else:
                params['rainstorm_risk_plot_count'] = self.rainstorm_risk_plot_count
        if self.region_codes:
            if isinstance(self.region_codes, list):
                for i in range(0, len(self.region_codes)):
                    element = self.region_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.region_codes[i] = element.to_alipay_dict()
            if hasattr(self.region_codes, 'to_alipay_dict'):
                params['region_codes'] = self.region_codes.to_alipay_dict()
            else:
                params['region_codes'] = self.region_codes
        if self.soil_moisture_risk_plot_count:
            if hasattr(self.soil_moisture_risk_plot_count, 'to_alipay_dict'):
                params['soil_moisture_risk_plot_count'] = self.soil_moisture_risk_plot_count.to_alipay_dict()
            else:
                params['soil_moisture_risk_plot_count'] = self.soil_moisture_risk_plot_count
        if self.total_area_sum:
            if hasattr(self.total_area_sum, 'to_alipay_dict'):
                params['total_area_sum'] = self.total_area_sum.to_alipay_dict()
            else:
                params['total_area_sum'] = self.total_area_sum
        if self.total_yield_sum:
            if hasattr(self.total_yield_sum, 'to_alipay_dict'):
                params['total_yield_sum'] = self.total_yield_sum.to_alipay_dict()
            else:
                params['total_yield_sum'] = self.total_yield_sum
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CropsStatisticsInfo()
        if 'addition_info' in d:
            o.addition_info = d['addition_info']
        if 'crop_code' in d:
            o.crop_code = d['crop_code']
        if 'drought_risk_plot_count' in d:
            o.drought_risk_plot_count = d['drought_risk_plot_count']
        if 'estimate_harvest_time_max' in d:
            o.estimate_harvest_time_max = d['estimate_harvest_time_max']
        if 'estimate_harvest_time_min' in d:
            o.estimate_harvest_time_min = d['estimate_harvest_time_min']
        if 'growth_general_area_sum' in d:
            o.growth_general_area_sum = d['growth_general_area_sum']
        if 'growth_general_plot_count' in d:
            o.growth_general_plot_count = d['growth_general_plot_count']
        if 'growth_stronger_area_sum' in d:
            o.growth_stronger_area_sum = d['growth_stronger_area_sum']
        if 'growth_stronger_plot_count' in d:
            o.growth_stronger_plot_count = d['growth_stronger_plot_count']
        if 'growth_strongest_area_sum' in d:
            o.growth_strongest_area_sum = d['growth_strongest_area_sum']
        if 'growth_strongest_plot_count' in d:
            o.growth_strongest_plot_count = d['growth_strongest_plot_count']
        if 'growth_weaker_area_sum' in d:
            o.growth_weaker_area_sum = d['growth_weaker_area_sum']
        if 'growth_weaker_plot_count' in d:
            o.growth_weaker_plot_count = d['growth_weaker_plot_count']
        if 'growth_weakest_area_sum' in d:
            o.growth_weakest_area_sum = d['growth_weakest_area_sum']
        if 'growth_weakest_plot_count' in d:
            o.growth_weakest_plot_count = d['growth_weakest_plot_count']
        if 'harvest_progress_value' in d:
            o.harvest_progress_value = d['harvest_progress_value']
        if 'harvested_area_sum' in d:
            o.harvested_area_sum = d['harvested_area_sum']
        if 'high_temp_risk_plot_count' in d:
            o.high_temp_risk_plot_count = d['high_temp_risk_plot_count']
        if 'low_temp_risk_plot_count' in d:
            o.low_temp_risk_plot_count = d['low_temp_risk_plot_count']
        if 'maturity_plot_count' in d:
            o.maturity_plot_count = d['maturity_plot_count']
        if 'not_harvested_area_sum' in d:
            o.not_harvested_area_sum = d['not_harvested_area_sum']
        if 'planting_area_sum' in d:
            o.planting_area_sum = d['planting_area_sum']
        if 'plot_area_sum' in d:
            o.plot_area_sum = d['plot_area_sum']
        if 'plot_count' in d:
            o.plot_count = d['plot_count']
        if 'rainstorm_risk_plot_count' in d:
            o.rainstorm_risk_plot_count = d['rainstorm_risk_plot_count']
        if 'region_codes' in d:
            o.region_codes = d['region_codes']
        if 'soil_moisture_risk_plot_count' in d:
            o.soil_moisture_risk_plot_count = d['soil_moisture_risk_plot_count']
        if 'total_area_sum' in d:
            o.total_area_sum = d['total_area_sum']
        if 'total_yield_sum' in d:
            o.total_yield_sum = d['total_yield_sum']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherFailShopInfo import VoucherFailShopInfo


class VoucherAvailableGeographyAllShopResultInfo(object):

    def __init__(self):
        self._fail_exclude_shop_infos = None
        self._success_exclude_shop_ids = None

    @property
    def fail_exclude_shop_infos(self):
        return self._fail_exclude_shop_infos

    @fail_exclude_shop_infos.setter
    def fail_exclude_shop_infos(self, value):
        if isinstance(value, list):
            self._fail_exclude_shop_infos = list()
            for i in value:
                if isinstance(i, VoucherFailShopInfo):
                    self._fail_exclude_shop_infos.append(i)
                else:
                    self._fail_exclude_shop_infos.append(VoucherFailShopInfo.from_alipay_dict(i))
    @property
    def success_exclude_shop_ids(self):
        return self._success_exclude_shop_ids

    @success_exclude_shop_ids.setter
    def success_exclude_shop_ids(self, value):
        if isinstance(value, list):
            self._success_exclude_shop_ids = list()
            for i in value:
                self._success_exclude_shop_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.fail_exclude_shop_infos:
            if isinstance(self.fail_exclude_shop_infos, list):
                for i in range(0, len(self.fail_exclude_shop_infos)):
                    element = self.fail_exclude_shop_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fail_exclude_shop_infos[i] = element.to_alipay_dict()
            if hasattr(self.fail_exclude_shop_infos, 'to_alipay_dict'):
                params['fail_exclude_shop_infos'] = self.fail_exclude_shop_infos.to_alipay_dict()
            else:
                params['fail_exclude_shop_infos'] = self.fail_exclude_shop_infos
        if self.success_exclude_shop_ids:
            if isinstance(self.success_exclude_shop_ids, list):
                for i in range(0, len(self.success_exclude_shop_ids)):
                    element = self.success_exclude_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.success_exclude_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.success_exclude_shop_ids, 'to_alipay_dict'):
                params['success_exclude_shop_ids'] = self.success_exclude_shop_ids.to_alipay_dict()
            else:
                params['success_exclude_shop_ids'] = self.success_exclude_shop_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherAvailableGeographyAllShopResultInfo()
        if 'fail_exclude_shop_infos' in d:
            o.fail_exclude_shop_infos = d['fail_exclude_shop_infos']
        if 'success_exclude_shop_ids' in d:
            o.success_exclude_shop_ids = d['success_exclude_shop_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InstCashPoolAccountMappingVO import InstCashPoolAccountMappingVO


class AlipayAccountCashpoolAccountBindModel(object):

    def __init__(self):
        self._cash_pool_account_mapping_vo_list = None
        self._cash_pool_id = None
        self._operator = None

    @property
    def cash_pool_account_mapping_vo_list(self):
        return self._cash_pool_account_mapping_vo_list

    @cash_pool_account_mapping_vo_list.setter
    def cash_pool_account_mapping_vo_list(self, value):
        if isinstance(value, list):
            self._cash_pool_account_mapping_vo_list = list()
            for i in value:
                if isinstance(i, InstCashPoolAccountMappingVO):
                    self._cash_pool_account_mapping_vo_list.append(i)
                else:
                    self._cash_pool_account_mapping_vo_list.append(InstCashPoolAccountMappingVO.from_alipay_dict(i))
    @property
    def cash_pool_id(self):
        return self._cash_pool_id

    @cash_pool_id.setter
    def cash_pool_id(self, value):
        self._cash_pool_id = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value


    def to_alipay_dict(self):
        params = dict()
        if self.cash_pool_account_mapping_vo_list:
            if isinstance(self.cash_pool_account_mapping_vo_list, list):
                for i in range(0, len(self.cash_pool_account_mapping_vo_list)):
                    element = self.cash_pool_account_mapping_vo_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cash_pool_account_mapping_vo_list[i] = element.to_alipay_dict()
            if hasattr(self.cash_pool_account_mapping_vo_list, 'to_alipay_dict'):
                params['cash_pool_account_mapping_vo_list'] = self.cash_pool_account_mapping_vo_list.to_alipay_dict()
            else:
                params['cash_pool_account_mapping_vo_list'] = self.cash_pool_account_mapping_vo_list
        if self.cash_pool_id:
            if hasattr(self.cash_pool_id, 'to_alipay_dict'):
                params['cash_pool_id'] = self.cash_pool_id.to_alipay_dict()
            else:
                params['cash_pool_id'] = self.cash_pool_id
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAccountCashpoolAccountBindModel()
        if 'cash_pool_account_mapping_vo_list' in d:
            o.cash_pool_account_mapping_vo_list = d['cash_pool_account_mapping_vo_list']
        if 'cash_pool_id' in d:
            o.cash_pool_id = d['cash_pool_id']
        if 'operator' in d:
            o.operator = d['operator']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppTestapiiSyncModel(object):

    def __init__(self):
        self._in_1 = None
        self._in_2 = None

    @property
    def in_1(self):
        return self._in_1

    @in_1.setter
    def in_1(self, value):
        self._in_1 = value
    @property
    def in_2(self):
        return self._in_2

    @in_2.setter
    def in_2(self, value):
        self._in_2 = value


    def to_alipay_dict(self):
        params = dict()
        if self.in_1:
            if hasattr(self.in_1, 'to_alipay_dict'):
                params['in_1'] = self.in_1.to_alipay_dict()
            else:
                params['in_1'] = self.in_1
        if self.in_2:
            if hasattr(self.in_2, 'to_alipay_dict'):
                params['in_2'] = self.in_2.to_alipay_dict()
            else:
                params['in_2'] = self.in_2
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppTestapiiSyncModel()
        if 'in_1' in d:
            o.in_1 = d['in_1']
        if 'in_2' in d:
            o.in_2 = d['in_2']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransBatchCreatesinglebatchModel(object):

    def __init__(self):
        self._batch_memo = None
        self._biz_type = None
        self._create_user_id = None
        self._ext_param = None
        self._pay_amount_single = None
        self._pay_amount_total = None
        self._real_items_total = None
        self._show_items_total = None

    @property
    def batch_memo(self):
        return self._batch_memo

    @batch_memo.setter
    def batch_memo(self, value):
        self._batch_memo = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def create_user_id(self):
        return self._create_user_id

    @create_user_id.setter
    def create_user_id(self, value):
        self._create_user_id = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def pay_amount_single(self):
        return self._pay_amount_single

    @pay_amount_single.setter
    def pay_amount_single(self, value):
        self._pay_amount_single = value
    @property
    def pay_amount_total(self):
        return self._pay_amount_total

    @pay_amount_total.setter
    def pay_amount_total(self, value):
        self._pay_amount_total = value
    @property
    def real_items_total(self):
        return self._real_items_total

    @real_items_total.setter
    def real_items_total(self, value):
        self._real_items_total = value
    @property
    def show_items_total(self):
        return self._show_items_total

    @show_items_total.setter
    def show_items_total(self, value):
        self._show_items_total = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_memo:
            if hasattr(self.batch_memo, 'to_alipay_dict'):
                params['batch_memo'] = self.batch_memo.to_alipay_dict()
            else:
                params['batch_memo'] = self.batch_memo
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.create_user_id:
            if hasattr(self.create_user_id, 'to_alipay_dict'):
                params['create_user_id'] = self.create_user_id.to_alipay_dict()
            else:
                params['create_user_id'] = self.create_user_id
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.pay_amount_single:
            if hasattr(self.pay_amount_single, 'to_alipay_dict'):
                params['pay_amount_single'] = self.pay_amount_single.to_alipay_dict()
            else:
                params['pay_amount_single'] = self.pay_amount_single
        if self.pay_amount_total:
            if hasattr(self.pay_amount_total, 'to_alipay_dict'):
                params['pay_amount_total'] = self.pay_amount_total.to_alipay_dict()
            else:
                params['pay_amount_total'] = self.pay_amount_total
        if self.real_items_total:
            if hasattr(self.real_items_total, 'to_alipay_dict'):
                params['real_items_total'] = self.real_items_total.to_alipay_dict()
            else:
                params['real_items_total'] = self.real_items_total
        if self.show_items_total:
            if hasattr(self.show_items_total, 'to_alipay_dict'):
                params['show_items_total'] = self.show_items_total.to_alipay_dict()
            else:
                params['show_items_total'] = self.show_items_total
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransBatchCreatesinglebatchModel()
        if 'batch_memo' in d:
            o.batch_memo = d['batch_memo']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'create_user_id' in d:
            o.create_user_id = d['create_user_id']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'pay_amount_single' in d:
            o.pay_amount_single = d['pay_amount_single']
        if 'pay_amount_total' in d:
            o.pay_amount_total = d['pay_amount_total']
        if 'real_items_total' in d:
            o.real_items_total = d['real_items_total']
        if 'show_items_total' in d:
            o.show_items_total = d['show_items_total']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ItemPriceVO import ItemPriceVO


class ItemSpuVO(object):

    def __init__(self):
        self._category_id = None
        self._head_img = None
        self._item_id = None
        self._out_item_id = None
        self._path = None
        self._price = None
        self._stock_num = None
        self._title = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def head_img(self):
        return self._head_img

    @head_img.setter
    def head_img(self, value):
        self._head_img = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def out_item_id(self):
        return self._out_item_id

    @out_item_id.setter
    def out_item_id(self, value):
        self._out_item_id = value
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        if isinstance(value, ItemPriceVO):
            self._price = value
        else:
            self._price = ItemPriceVO.from_alipay_dict(value)
    @property
    def stock_num(self):
        return self._stock_num

    @stock_num.setter
    def stock_num(self, value):
        self._stock_num = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.head_img:
            if hasattr(self.head_img, 'to_alipay_dict'):
                params['head_img'] = self.head_img.to_alipay_dict()
            else:
                params['head_img'] = self.head_img
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.out_item_id:
            if hasattr(self.out_item_id, 'to_alipay_dict'):
                params['out_item_id'] = self.out_item_id.to_alipay_dict()
            else:
                params['out_item_id'] = self.out_item_id
        if self.path:
            if hasattr(self.path, 'to_alipay_dict'):
                params['path'] = self.path.to_alipay_dict()
            else:
                params['path'] = self.path
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.stock_num:
            if hasattr(self.stock_num, 'to_alipay_dict'):
                params['stock_num'] = self.stock_num.to_alipay_dict()
            else:
                params['stock_num'] = self.stock_num
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemSpuVO()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'head_img' in d:
            o.head_img = d['head_img']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'out_item_id' in d:
            o.out_item_id = d['out_item_id']
        if 'path' in d:
            o.path = d['path']
        if 'price' in d:
            o.price = d['price']
        if 'stock_num' in d:
            o.stock_num = d['stock_num']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ArrangementOpenQueryResultVO import ArrangementOpenQueryResultVO


class MybankCreditLoanapplyArrangementQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoanapplyArrangementQueryResponse, self).__init__()
        self._arrangement_query_result = None

    @property
    def arrangement_query_result(self):
        return self._arrangement_query_result

    @arrangement_query_result.setter
    def arrangement_query_result(self, value):
        if isinstance(value, list):
            self._arrangement_query_result = list()
            for i in value:
                if isinstance(i, ArrangementOpenQueryResultVO):
                    self._arrangement_query_result.append(i)
                else:
                    self._arrangement_query_result.append(ArrangementOpenQueryResultVO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoanapplyArrangementQueryResponse, self).parse_response_content(response_content)
        if 'arrangement_query_result' in response:
            self.arrangement_query_result = response['arrangement_query_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GiftCardTemplate(object):

    def __init__(self):
        self._business_params = None
        self._denomination = None
        self._effective_end_date = None
        self._effective_period = None
        self._effective_start_date = None
        self._end_date = None
        self._gift_card_template_name = None
        self._price = None
        self._settle_account_no = None
        self._start_date = None
        self._stock_num = None
        self._valid_date = None
        self._valid_period = None
        self._valid_type = None

    @property
    def business_params(self):
        return self._business_params

    @business_params.setter
    def business_params(self, value):
        self._business_params = value
    @property
    def denomination(self):
        return self._denomination

    @denomination.setter
    def denomination(self, value):
        self._denomination = value
    @property
    def effective_end_date(self):
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, value):
        self._effective_end_date = value
    @property
    def effective_period(self):
        return self._effective_period

    @effective_period.setter
    def effective_period(self, value):
        self._effective_period = value
    @property
    def effective_start_date(self):
        return self._effective_start_date

    @effective_start_date.setter
    def effective_start_date(self, value):
        self._effective_start_date = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def gift_card_template_name(self):
        return self._gift_card_template_name

    @gift_card_template_name.setter
    def gift_card_template_name(self, value):
        self._gift_card_template_name = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def settle_account_no(self):
        return self._settle_account_no

    @settle_account_no.setter
    def settle_account_no(self, value):
        self._settle_account_no = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def stock_num(self):
        return self._stock_num

    @stock_num.setter
    def stock_num(self, value):
        self._stock_num = value
    @property
    def valid_date(self):
        return self._valid_date

    @valid_date.setter
    def valid_date(self, value):
        self._valid_date = value
    @property
    def valid_period(self):
        return self._valid_period

    @valid_period.setter
    def valid_period(self, value):
        self._valid_period = value
    @property
    def valid_type(self):
        return self._valid_type

    @valid_type.setter
    def valid_type(self, value):
        self._valid_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_params:
            if hasattr(self.business_params, 'to_alipay_dict'):
                params['business_params'] = self.business_params.to_alipay_dict()
            else:
                params['business_params'] = self.business_params
        if self.denomination:
            if hasattr(self.denomination, 'to_alipay_dict'):
                params['denomination'] = self.denomination.to_alipay_dict()
            else:
                params['denomination'] = self.denomination
        if self.effective_end_date:
            if hasattr(self.effective_end_date, 'to_alipay_dict'):
                params['effective_end_date'] = self.effective_end_date.to_alipay_dict()
            else:
                params['effective_end_date'] = self.effective_end_date
        if self.effective_period:
            if hasattr(self.effective_period, 'to_alipay_dict'):
                params['effective_period'] = self.effective_period.to_alipay_dict()
            else:
                params['effective_period'] = self.effective_period
        if self.effective_start_date:
            if hasattr(self.effective_start_date, 'to_alipay_dict'):
                params['effective_start_date'] = self.effective_start_date.to_alipay_dict()
            else:
                params['effective_start_date'] = self.effective_start_date
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.gift_card_template_name:
            if hasattr(self.gift_card_template_name, 'to_alipay_dict'):
                params['gift_card_template_name'] = self.gift_card_template_name.to_alipay_dict()
            else:
                params['gift_card_template_name'] = self.gift_card_template_name
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.settle_account_no:
            if hasattr(self.settle_account_no, 'to_alipay_dict'):
                params['settle_account_no'] = self.settle_account_no.to_alipay_dict()
            else:
                params['settle_account_no'] = self.settle_account_no
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.stock_num:
            if hasattr(self.stock_num, 'to_alipay_dict'):
                params['stock_num'] = self.stock_num.to_alipay_dict()
            else:
                params['stock_num'] = self.stock_num
        if self.valid_date:
            if hasattr(self.valid_date, 'to_alipay_dict'):
                params['valid_date'] = self.valid_date.to_alipay_dict()
            else:
                params['valid_date'] = self.valid_date
        if self.valid_period:
            if hasattr(self.valid_period, 'to_alipay_dict'):
                params['valid_period'] = self.valid_period.to_alipay_dict()
            else:
                params['valid_period'] = self.valid_period
        if self.valid_type:
            if hasattr(self.valid_type, 'to_alipay_dict'):
                params['valid_type'] = self.valid_type.to_alipay_dict()
            else:
                params['valid_type'] = self.valid_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GiftCardTemplate()
        if 'business_params' in d:
            o.business_params = d['business_params']
        if 'denomination' in d:
            o.denomination = d['denomination']
        if 'effective_end_date' in d:
            o.effective_end_date = d['effective_end_date']
        if 'effective_period' in d:
            o.effective_period = d['effective_period']
        if 'effective_start_date' in d:
            o.effective_start_date = d['effective_start_date']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'gift_card_template_name' in d:
            o.gift_card_template_name = d['gift_card_template_name']
        if 'price' in d:
            o.price = d['price']
        if 'settle_account_no' in d:
            o.settle_account_no = d['settle_account_no']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'stock_num' in d:
            o.stock_num = d['stock_num']
        if 'valid_date' in d:
            o.valid_date = d['valid_date']
        if 'valid_period' in d:
            o.valid_period = d['valid_period']
        if 'valid_type' in d:
            o.valid_type = d['valid_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceSportsFacepayskinReceiveModel(object):

    def __init__(self):
        self._client_version = None
        self._expire_date = None
        self._open_id = None
        self._skin_id = None
        self._user_id = None

    @property
    def client_version(self):
        return self._client_version

    @client_version.setter
    def client_version(self, value):
        self._client_version = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def skin_id(self):
        return self._skin_id

    @skin_id.setter
    def skin_id(self, value):
        self._skin_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.client_version:
            if hasattr(self.client_version, 'to_alipay_dict'):
                params['client_version'] = self.client_version.to_alipay_dict()
            else:
                params['client_version'] = self.client_version
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.skin_id:
            if hasattr(self.skin_id, 'to_alipay_dict'):
                params['skin_id'] = self.skin_id.to_alipay_dict()
            else:
                params['skin_id'] = self.skin_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceSportsFacepayskinReceiveModel()
        if 'client_version' in d:
            o.client_version = d['client_version']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'skin_id' in d:
            o.skin_id = d['skin_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


